@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1995-2008 Index Data
+   Copyright (C) 1994-2009 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -261,9 +261,9 @@ int cf_commit(CFile cf)
         return -1;
     }
     yaz_log(log_level, "cf_commit: state=%d", cf->head.state);
-    if (cf->head.state == 1)
+    if (cf->head.state == CFILE_STATE_HASH)
         return cf_commit_hash(cf);
-    else if (cf->head.state == 2)
+    else if (cf->head.state == CFILE_STATE_FLAT)
         return cf_commit_flat(cf);
     else
     {
@@ -275,6 +275,7 @@ int cf_commit(CFile cf)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
