@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1995-2008 Index Data
+   Copyright (C) 1994-2009 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -291,6 +291,7 @@ int zebra_register_statistics (ZebraHandle zh, int dumpdict)
     }
     fprintf (stdout, "%7d-        %7d\n",
              prev, stat_info.isam_occurrences[i]);
+    rec_prstat(zh->reg->records, 0);
     xmalloc_trav("unfreed"); /*! while hunting memory leaks */    
     zebra_end_read (zh);
     return 0;
@@ -299,6 +300,7 @@ int zebra_register_statistics (ZebraHandle zh, int dumpdict)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
