@@ -1,5 +1,5 @@
 /* This file is part of the Zebra server.
-   Copyright (C) 1995-2008 Index Data
+   Copyright (C) 1994-2009 Index Data
 
 Zebra is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -38,8 +38,13 @@ static void tst(int argc, char **argv)
         = "<record xmlns=\"http://www.indexdata.com/zebra/\" sysno=\"2\" base=\"Default\" type=\"grs.sgml\" rank=\"0\" size=\"41\" set=\"zebra::meta\"/>\n";
 
     const char * zebra_xml_index_title_p
-        = "<record xmlns=\"http://www.indexdata.com/zebra/\" sysno=\"2\" set=\"zebra::index::title:p/\">\n"
+        = "<record xmlns=\"http://www.indexdata.com/zebra/\" sysno=\"2\" set=\"zebra::index::title:p\">\n"
 "  <index name=\"title\" type=\"p\" seq=\"4\">my title</index>\n"
+"</record>\n";
+
+    const char * zebra_xml_index_title_s
+        = "<record xmlns=\"http://www.indexdata.com/zebra/\" sysno=\"2\" set=\"zebra::index::title:s\">\n"
+"  <index name=\"title\" type=\"s\">my title</index>\n"
 "</record>\n";
 
     ZebraService zs = tl_start_up(0, argc, argv);
@@ -75,6 +80,10 @@ static void tst(int argc, char **argv)
                                         yaz_oid_recsyn_xml,
                                         zebra_xml_index_title_p), ZEBRA_OK);
     
+    YAZ_CHECK_EQ(tl_fetch_first_compare(zh, "zebra::index::title:s", 
+                                        yaz_oid_recsyn_xml,
+                                        zebra_xml_index_title_s), ZEBRA_OK);
+    
     YAZ_CHECK_EQ(tl_fetch_first_compare(zh, "zebra::nonexistent", 
                                         yaz_oid_recsyn_xml, ""), ZEBRA_OK);
     
@@ -89,6 +98,7 @@ TL_MAIN
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
